'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var jsonMerger = require('json-merger');
var fsPromises = require('fs/promises');
var fs = require('fs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var jsonMerger__namespace = /*#__PURE__*/_interopNamespace(jsonMerger);
var fsPromises__default = /*#__PURE__*/_interopDefaultLegacy(fsPromises);
var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);

const ensureDirectoryExists = async (filePath) => {
  if (!fs__default["default"].existsSync(filePath)) {
    await fsPromises__default["default"].mkdir(filePath);
  }
};

function createJsonMergeFilesAction() {
  return pluginScaffolderBackend.createTemplateAction({
    id: "json:merge-files",
    description: "Merges two or more files",
    supportsDryRun: true,
    schema: {
      input: {
        type: "object",
        required: ["inputFiles", "outputFileName"],
        properties: {
          inputFiles: {
            title: "Input files",
            description: "The files in the working directory to merge",
            type: "array",
            items: {
              type: "string"
            }
          },
          outputFileName: {
            title: "Output file name",
            description: "The name of the file to write to",
            type: "string"
          },
          outputFilePath: {
            title: "Output file path",
            description: "The path to output the file to. Defaults to the task's working directory",
            type: "string"
          },
          jsonMergeOptions: {
            title: "Json merge options",
            description: "Options to pass to the JSON mergeFiles function",
            type: "object"
          }
        }
      }
    },
    async handler(ctx) {
      var _a;
      try {
        console.log(`Running json merge in ${ctx.workspacePath}`);
        ctx.logger.info(`Running json merge in ${ctx.workspacePath}`);
        const config = {
          ...ctx.input.jsonMergeOptions,
          cwd: ctx.workspacePath
        };
        const result = jsonMerger__namespace.mergeFiles(ctx.input.inputFiles, config);
        const outputPathAndFile = `${ctx.workspacePath}/${(_a = ctx.input.outputFilePath) != null ? _a : ""}/${ctx.input.outputFileName}`.replace("//", "/");
        if (ctx.input.outputFilePath) {
          await ensureDirectoryExists(
            `${ctx.workspacePath}/${ctx.input.outputFilePath}`
          );
        }
        const resultJson = JSON.stringify(result, null, 2);
        ctx.logger.info(
          `Writing result to output with filePath ${ctx.workspacePath}/${ctx.input.outputFilePath}`
        );
        ctx.logger.info(`Result: ${resultJson}`);
        await fsPromises__default["default"].writeFile(outputPathAndFile, resultJson);
      } catch (err) {
        console.error(err);
        ctx.logger.error(err);
        throw err;
      }
    }
  });
}

function createJsonMergeFileAction() {
  return pluginScaffolderBackend.createTemplateAction({
    id: "json:merge-file",
    description: "Merges two or more files",
    supportsDryRun: true,
    schema: {
      input: {
        type: "object",
        required: ["inputFile", "outputFileName"],
        properties: {
          inputFile: {
            title: "Input file",
            description: "The file in the working directory to merge",
            type: "string"
          },
          outputFileName: {
            title: "Output file name",
            description: "The name of the file to write to",
            type: "string"
          },
          outputFilePath: {
            title: "Output file path",
            description: "The path to output the file to. Defaults to the task's working directory",
            type: "string"
          },
          jsonMergeOptions: {
            title: "Json merge options",
            description: "Options to pass to the JSON mergeFiles function",
            type: "object"
          }
        }
      }
    },
    async handler(ctx) {
      var _a;
      try {
        console.log(`Running json merge in ${ctx.workspacePath}`);
        ctx.logger.info(`Running json merge in ${ctx.workspacePath}`);
        const config = {
          ...ctx.input.jsonMergeOptions,
          cwd: ctx.workspacePath
        };
        ctx.logger.info(`input file: ${ctx.input.inputFile}`);
        const result = jsonMerger__namespace.mergeFile(ctx.input.inputFile, config);
        const outputPathAndFile = `${ctx.workspacePath}/${(_a = ctx.input.outputFilePath) != null ? _a : ""}/${ctx.input.outputFileName}`.replace("//", "/");
        if (ctx.input.outputFilePath) {
          await ensureDirectoryExists(
            `${ctx.workspacePath}/${ctx.input.outputFilePath}`
          );
        }
        const resultJson = JSON.stringify(result, null, 2);
        ctx.logger.info(
          `Writing result to output with filePath ${ctx.workspacePath}/${ctx.input.outputFilePath}`
        );
        ctx.logger.info(`Result: ${resultJson}`);
        await fsPromises__default["default"].writeFile(outputPathAndFile, resultJson);
      } catch (err) {
        console.error(err);
        ctx.logger.error(err);
        throw err;
      }
    }
  });
}

exports.createJsonMergeFileAction = createJsonMergeFileAction;
exports.createJsonMergeFilesAction = createJsonMergeFilesAction;
//# sourceMappingURL=index.cjs.js.map
